#!/bin/sh

. ./host.conf

setkey -c <<EOF

flush;
spdflush;

# Bypass ICMPv6 NS+NA
spdadd -6 ::/0 ::/0 icmp6 135,0 -P out none;
spdadd -6 ::/0 ::/0 icmp6 136,0 -P out none;

# IPv4
spdadd ${LOCAL_IPV4} ${REMOTE_IPV4} any -P out ipsec esp/transport//require;
spdadd ${REMOTE_IPV4} ${LOCAL_IPV4} any -P in ipsec esp/transport//require;
add ${REMOTE_IPV4} ${LOCAL_IPV4} esp 51966 -m transport -E rijndael-cbc "1111111111111111";
add ${LOCAL_IPV4} ${REMOTE_IPV4} esp 48879 -m transport -E rijndael-cbc "1111111111111112";

# IPv6
spdadd -6 ${LOCAL_IPV6} ${REMOTE_IPV6} any -P out ipsec esp/transport//require;
spdadd -6 ${REMOTE_IPV6} ${LOCAL_IPV6} any -P in ipsec esp/transport//require;
add -6 ${REMOTE_IPV6} ${LOCAL_IPV6} esp 57005 -m transport -E rijndael-cbc "1111111111111113";
add -6 ${LOCAL_IPV6} ${REMOTE_IPV6} esp 49374 -m transport -E rijndael-cbc "1111111111111114";

# IPv6 LLA
spdadd -6 ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} any -P out ipsec esp/transport//require;
spdadd -6 ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} any -P in ipsec esp/transport//require;
add -6 ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} esp 2989 -m transport -E rijndael-cbc "1111111111111115";
add -6 ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} esp 47806 -m transport -E rijndael-cbc "1111111111111116";
EOF

cat <<EOF
-------------------------- TEST 01 --------------------------
# Simple IPsec configuration:
# proto:	ESP
# mode:		transport
# level:	require
#
# Expected result:
# ESP traffic between hosts ${LOCAL_NAME} and ${REMOTE_NAME}
# Non-ESP inbound IPv4/IPv6 traffic from partner host should be
# rejected (except ICMPv6 NS and NA).

# Use following commands to check results:
# tcpdump -ni ${LOCAL_IFNAME}
# ping -c 3 -S ${LOCAL_IPV4} ${REMOTE_IPV4}
# ping6 -c 3 -S ${LOCAL_IPV6} ${REMOTE_IPV6}
# ping6 -c 3 -S ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME}
EOF

