#!/bin/sh

. ./host.conf

setkey -c <<EOF

flush;
spdflush;

# IPv4-IPv4
spdadd ${LOCAL_IPV4GIF} ${REMOTE_IPV4GIF} any -P out ipsec esp/tunnel/${LOCAL_IPV4}-${REMOTE_IPV4}/require;
spdadd ${REMOTE_IPV4GIF} ${LOCAL_IPV4GIF} any -P in ipsec esp/tunnel/${REMOTE_IPV4}-${LOCAL_IPV4}/require;
# IPv4-IPv6
spdadd -6 ${LOCAL_IPV6GIF} ${REMOTE_IPV6GIF} any -P out esp/tunnel/${LOCAL_IPV4}-${REMOTE_IPV4}/require;
spdadd -6 ${REMOTE_IPV6GIF} ${LOCAL_IPV6GIF} any -P in esp/tunnel/${REMOTE_IPV4}-${LOCAL_IPV4}/require;
add ${LOCAL_IPV4} ${REMOTE_IPV4} esp 51966 -m tunnel -E rijndael-cbc "1111111111111111";
add ${REMOTE_IPV4} ${LOCAL_IPV4} esp 48879 -m tunnel -E rijndael-cbc "1111111111111112";

# IPv6LLA-IPv6
spdadd -6 ${LOCAL_IPV6} ${REMOTE_IPV6} any -P out ipsec esp/tunnel/${LOCAL_IPV6LLA}%${LOCAL_IFNAME}-${REMOTE_IPV6LLA}%${LOCAL_IFNAME}/require;
spdadd -6 ${REMOTE_IPV6} ${LOCAL_IPV6} any -P out ipsec esp/tunnel/${REMOTE_IPV6LLA}%${LOCAL_IFNAME}-${LOCAL_IPV6LLA}%${LOCAL_IFNAME}/require;
add -6 ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} esp 57005 -m tunnel -E rijndael-cbc "1111111111111113";
add -6 ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} esp 49374 -m tunnel -E rijndael-cbc "1111111111111114";

# Bypass ICMPv6 NS+NA
spdadd -6 ::/0 ::/0 icmp6 135,0 -P out none;
spdadd -6 ::/0 ::/0 icmp6 136,0 -P out none;
EOF

cat <<EOF
-------------------------- TEST 02 --------------------------
# Simple IPsec configuration:
# proto:	ESP
# mode:		tunnel
# level:	require
#
# Expected result:
# ESP traffic between hosts ${LOCAL_NAME} and ${REMOTE_NAME}
# Non-ESP inbound IPv4/IPv6 traffic from partner host should be
# rejected (except ICMPv6 NS and NA).

# Use following commands to check results:
# tcpdump -ni ${LOCAL_IFNAME}
# ping -c 3 -S ${LOCAL_IPV4} ${REMOTE_IPV4}
# ping6 -c 3 -S ${LOCAL_IPV6} ${REMOTE_IPV6}
# ping6 -c 3 -S ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME}
EOF

