#!/bin/sh

. ./host.conf

setkey -c <<EOF

flush;
spdflush;

# Bypass ICMPv6 NS+NA
spdadd -6 ::/0 ::/0 icmp6 135,0 -P out none;
spdadd -6 ::/0 ::/0 icmp6 136,0 -P out none;

# IPv4
spdadd ${LOCAL_IPV4} ${REMOTE_IPV4} any -P out ipsec ah/transport//require;
spdadd ${REMOTE_IPV4} ${LOCAL_IPV4} any -P in ipsec ah/transport//require;
add ${LOCAL_IPV4} ${REMOTE_IPV4} ah 51966 -m transport -A hmac-md5 "1111111111111111";
add ${REMOTE_IPV4} ${LOCAL_IPV4} ah 48879 -m transport -A hmac-md5 "1111111111111112";

# IPv6
spdadd -6 ${LOCAL_IPV6} ${REMOTE_IPV6} any -P out ipsec ah/transport//require;
spdadd -6 ${REMOTE_IPV6} ${LOCAL_IPV6} any -P in ipsec ah/transport//require;
add -6 ${LOCAL_IPV6} ${REMOTE_IPV6} ah 57005 -m transport -A hmac-md5 "1111111111111113";
add -6 ${REMOTE_IPV6} ${LOCAL_IPV6} ah 49374 -m transport -A hmac-md5 "1111111111111114";

# IPv6 LLA
spdadd -6 ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} any -P out ipsec ah/transport//require;
spdadd -6 ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} any -P in ipsec ah/transport//require;
add -6 ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ah 2989 -m transport -A hmac-md5 "1111111111111115";
add -6 ${REMOTE_IPV6LLA}%${LOCAL_IFNAME} ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ah 47806 -m transport -A hmac-md5 "1111111111111116";
EOF

cat <<EOF
-------------------------- TEST 01 --------------------------
# Simple IPsec configuration:
# proto:	AH
# mode:		transport
# level:	require
#
# Expected result:
# AH traffic between hosts ${LOCAL_NAME} and ${REMOTE_NAME}
# Non-AH inbound IPv4/IPv6 traffic from partner host should be
# rejected (except ICMPv6 NS and NA).

# Use following commands to check results:
# tcpdump -ni ${LOCAL_IFNAME}
# ping -c 3 -S ${LOCAL_IPV4} ${REMOTE_IPV4}
# ping6 -c 3 -S ${LOCAL_IPV6} ${REMOTE_IPV6}
# ping6 -c 3 -S ${LOCAL_IPV6LLA}%${LOCAL_IFNAME} ${REMOTE_IPV6LLA}%${LOCAL_IFNAME}
EOF

